/*
 * Licensed to the Sakai Foundation (SF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The SF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 */
package org.sakaiproject.nakamura.lite.storage;

import java.util.Iterator;

/**
 * Disposable Iterators must be closed when they have been used. If they are
 * registered with a disposer, they should be disposed of by the disposer and
 * there is no requirement for the user of the Iterator to dispose of the
 * iterator. Failure to dispose a DispsableIterator will cause resource
 * exhaustion. eg out of SQL cursors, out of files, out of memory.
 * 
 * @author ieb
 * 
 * @param <T>
 */
public interface DisposableIterator<T> extends Iterator<T>, Disposable {
}
